var gulp = require('gulp'),
    notify = require('gulp-notify'),
    plumber = require('gulp-plumber'),
    concat = require('gulp-concat'),
    rename = require('gulp-rename'),
    uglify = require('gulp-uglify'),
    eslint = require('gulp-eslint'),
    header = require('gulp-header'),
    config = require('./package.json');

gulp.task('lint', function() {
    return gulp.src(['src/main.js', 'src/*.js', 'src/**/*.js', '!src/dataTableList.1.js'])
        .pipe(eslint())
        .pipe(eslint.result(result => {
            // Called for each ESLint result.
            console.log(`ESLint result: ${result.filePath}`);
            console.log(`# Messages: ${result.messages.length}`);
            console.log(`# Warnings: ${result.warningCount}`);
            console.log(`# Errors: ${result.errorCount}`);
        }))
        .pipe(eslint.results(results => {
            // Called once for all ESLint results.
            console.log(`Total Results: ${results.length}`);
            console.log(`Total Warnings: ${results.warningCount}`);
            console.log(`Total Errors: ${results.errorCount}`);
        }))
        .pipe(eslint.format())
        .pipe(eslint.failAfterError());
});

gulp.task('build', function() {
    gulp.src(['src/main.js', 'src/*.js', 'src/**/*.js', '!src/dataTableList.1.js'])
        .pipe(plumber({
            errorHandler: notify.onError('Error: <%= error.message %>')
        }))
        .pipe(concat('JSutilfuc-' + config.version + '.js'))
        .pipe(gulp.dest('dist/'))
        .pipe(rename({
            suffix: '.min'
        }))
        .pipe(uglify())
        .pipe(header('/**\n* 版权所有\n' +
            '* 文档说明:\n' +
            config.description +
            '* 文档更新:\n' +
            config.revise +
            '* 创建时间： 2017-11-20\n' +
            '* 作者: 吴波\n' +
            '* 版本: ' +
            config.version +
            '\n* github:' + config.repository.url + '\n*/\n'))
        .pipe(gulp.dest('dist/'));
})

gulp.task('Watch', function() {
    gulp.watch(['src/**/*.js'], ['lint', 'build']);
});

gulp.task('default', ['Watch']);